==> ui-1.7.2-sources.jar: nanorep/nanowidget/Components/ConfirmationDialogFragment.java <==
package nanorep.nanowidget.Components;

import android.content.Context;
import android.content.DialogInterface;

import android.view.View;
import android.widget.TextView;

import nanorep.nanowidget.R;

/**
 * Created by obenoved on 9 Jan 2018.
 */

public class ConfirmationDialogFragment extends android.support.v7.app.AlertDialog.Builder {

    private TextView confirmationTextView;
    private TextView titleTextView;
    private OnOkClick mListener;
    private android.support.v7.app.AlertDialog alert;

    public interface OnOkClick {
        void okClicked();
    }

    public ConfirmationDialogFragment(Context context, final View confirmationView, String confirmationBody, String confirmationButton, String confirmationTitle){
        super(context);
        setView(confirmationView);

        titleTextView = (TextView) confirmationView.findViewById(R.id.fragment_dialog_confirm_title);
        confirmationTextView = (TextView) confirmationView.findViewById(R.id.fragment_dialog_confirm_text);

        titleTextView.setText(confirmationTitle);
        confirmationTextView.setText(confirmationBody);

        setPositiveButton(confirmationButton, new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialogInterface, int i) {
                alert.dismiss();
            }
        });

        alert = create();
        alert.show();
    }

    public ConfirmationDialogFragment(Context context, final View confirmationView, String confirmationBody, String confirmationButton, String confirmationTitle, final OnOkClick listener) {
        super(context);
        setView(confirmationView);

        mListener = listener;

        titleTextView = (TextView) confirmationView.findViewById(R.id.fragment_dialog_confirm_title);
        confirmationTextView = (TextView) confirmationView.findViewById(R.id.fragment_dialog_confirm_text);

        titleTextView.setText(confirmationTitle);
        confirmationTextView.setText(confirmationBody);

        setPositiveButton(confirmationButton, new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialogInterface, int i) {
                mListener.okClicked();
                alert.dismiss();

            }
        });

        alert = create();
        alert.show();
    }
}

==> ui-1.7.5-sources.jar: nanorep/nanowidget/Components/ConfirmationDialogFragment.java <==
package nanorep.nanowidget.Components;

import android.content.Context;
import android.content.DialogInterface;

import android.view.View;
import android.widget.TextView;

import nanorep.nanowidget.R;

/**
 * Created by obenoved on 9 Jan 2018.
 */

public class ConfirmationDialogFragment extends android.support.v7.app.AlertDialog.Builder {

    private TextView confirmationTextView;
    private TextView titleTextView;
    private OnOkClick mListener;
    private android.support.v7.app.AlertDialog alert;

    public interface OnOkClick {
        void okClicked();
    }

    public ConfirmationDialogFragment(Context context, final View confirmationView, String confirmationBody, String confirmationButton, String confirmationTitle){
        super(context);
        setView(confirmationView);

        titleTextView = confirmationView.findViewById(R.id.fragment_dialog_confirm_title);
        confirmationTextView = confirmationView.findViewById(R.id.fragment_dialog_confirm_text);

        titleTextView.setText(confirmationTitle);
        confirmationTextView.setText(confirmationBody);

        setPositiveButton(confirmationButton, new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialogInterface, int i) {
                alert.dismiss();
            }
        });

        alert = create();
        alert.show();
    }

    public ConfirmationDialogFragment(Context context, final View confirmationView, String confirmationBody, String confirmationButton, String confirmationTitle, final OnOkClick listener) {
        super(context);
        setView(confirmationView);

        mListener = listener;

        titleTextView = confirmationView.findViewById(R.id.fragment_dialog_confirm_title);
        confirmationTextView = confirmationView.findViewById(R.id.fragment_dialog_confirm_text);

        titleTextView.setText(confirmationTitle);
        confirmationTextView.setText(confirmationBody);

        setPositiveButton(confirmationButton, new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialogInterface, int i) {
                mListener.okClicked();
                alert.dismiss();

            }
        });

        alert = create();
        alert.show();
    }
}
